/****************************************************************

			flex.h

*****************************************************************/

/* flags for vector application */

#define NORMAL 0
#define INVERT 1


/* #define THOU_TO_STEPS  10.16 */

#define THOU_TO_STEPS  ( MOTOR_RESOLUTION / 1000 )

#define THERM_COEF  .000008	/* % expansion / deg f */

#define TZERO       68.0


/* constants used in stage distortion calculations,
                                  units in terms of encoder steps */
/* These are results from measurements of the grid 7/25/95 by SCB */

#define XSCALE_ADJUST  4.5/10000.0	/* dx vs x, linear adjustment */
#define YSCALE_ADJUST  0.0/10000.0	/* dy vs y, linear adjustment */
#define DXY_LINEAR     4.8/10000.0	/* dx vs y, linear adjustment */
#define DYX_LINEAR    -1.8/10000.0	/* dy vs x, linear adjustment */
#define DXY_QUAD      -.156/1.0e8	/* dx vs y, quadratic adjustment */
#define DYY_QUAD       .156/1.0e8	/* dy vs y, quadratic adjustment */

/* constants used to do final tweaking of positional error, 
                                 units are in terms of encoder steps */
/* These were derived from on-sky evaluation of fiber positioning */
/*         done  on 9/95 by SCB */

/* for plate scale of 9.4000 */
#define FDXX_LINEAR 3.57976e-4 		/* Final tweak for dx vs x, linear */
#define FDYY_LINEAR 2.56643e-4		/* Final tweak for dy vs y, linear */

/* for plate scale of 9.4032 */
/*
#define FDXX_LINEAR 6.98402e-4 		
#define FDYY_LINEAR 5.97069e-4	
*/

#define FDXX_QUAD   3.58795e-9  	/* Final tweak for dx vs x, quadratic */
#define FDYY_QUAD   2.64441e-9  	/* Final tweak for dy vs y, quadratic */
 
/* End of parameters for positional error compensation */

#define PERIOD	 ( ( 2.0 * M_PI ) / 2032.0 )

#define XZERO	-400.0

/* constants used in flexure calculations */


/* Y gravitational terms */

#define Gy 	-4.605



/* X gravitational terms */

#define Gx1	-0.7255
#define Gx2	-0.6134




/* structures */

struct envData{

   double ra;	
   double dec;		/* radians */
   double ha;		/* radians */
   double temp;	 	/* degrees F */

   double theta;	/* these two are temporary */
   double phi;

};


/* global functions/variables */

extern int warpFlag;
extern int thermFlag;
extern int flexFlag;

extern struct envData  PhysicalEnvironment;

extern void coordCorrect();

extern void correctWarp();
extern void correctTherm();
extern void correctFlex();

extern void applyVec();

